Class: Google::Cloud::GkeRecommender::V1::Cost

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb

Overview

Cost for running a model deployment on a given instance type. Currently, only USD currency code is supported.

Instance Attribute Summary collapse

Instance Attribute Details

#cost_per_million_input_tokens::Google::Cloud::GkeRecommender::V1::Amount

Returns Optional. The cost per million input tokens. $/input token = ($/output token) / output-to-input-cost-ratio.

Returns:



307
308
309
310
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 307

class Cost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cost_per_million_output_tokens::Google::Cloud::GkeRecommender::V1::Amount

Returns Optional. The cost per million output tokens, calculated as: $/output token = GPU $/s / (1/output-to-input-cost-ratio * input tokens/s + output tokens/s).

Returns:



307
308
309
310
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 307

class Cost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_input_cost_ratio::Float

Returns Optional. The output-to-input cost ratio. This determines how the total GPU cost is split between input and output tokens. If not provided, 4.0 is used, assuming a 4:1 output:input cost ratio.

Returns:

  • (::Float)

    Optional. The output-to-input cost ratio. This determines how the total GPU cost is split between input and output tokens. If not provided, 4.0 is used, assuming a 4:1 output:input cost ratio.



307
308
309
310
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 307

class Cost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pricing_model::String

Returns Optional. The pricing model used to calculate the cost. Can be one of: 3-years-cud, 1-year-cud, on-demand, spot. If not provided, spot will be used.

Returns:

  • (::String)

    Optional. The pricing model used to calculate the cost. Can be one of: 3-years-cud, 1-year-cud, on-demand, spot. If not provided, spot will be used.



307
308
309
310
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 307

class Cost
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end