Class: Google::Cloud::GkeRecommender::V1::FetchModelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::FetchModelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Request message for GkeInferenceQuickstart.FetchModels.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The target number of results to return in a single response. If not specified, a default value will be chosen by the service. Note that the response may include a partial list and a caller should only rely on the response's next_page_token to determine if there are more instances left to be queried.
42 43 44 45 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 42 class FetchModelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The value of
next_page_token
received from a previous FetchModelsRequest call.
Provide this to retrieve the subsequent page in a multi-page list of
results. When paginating, all other parameters provided to
FetchModelsRequest must match the call that provided the page token.
42 43 44 45 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 42 class FetchModelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |