Class: Google::Cloud::GkeRecommender::V1::FetchModelsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::FetchModelsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Response message for GkeInferenceQuickstart.FetchModels.
Instance Attribute Summary collapse
-
#models ⇒ ::Array<::String>
readonly
Output only.
-
#next_page_token ⇒ ::String
readonly
Output only.
Instance Attribute Details
#models ⇒ ::Array<::String> (readonly)
Returns Output only. List of available models. Open-source models follow the
Huggingface Hub owner/model_name format.
60 61 62 63 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 60 class FetchModelsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String (readonly)
Output only. A token which may be sent as
[page_token][FetchModelsResponse.page_token] in a subsequent
FetchModelsResponse call to retrieve the next page of results.
If this field is omitted or empty, then there are no more results to
return.
60 61 62 63 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 60 class FetchModelsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |