Class: Google::Cloud::GkeRecommender::V1::FetchProfilesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#model::String

Optional. The model to filter profiles by. Open-source models follow the Huggingface Hub owner/model_name format. If not provided, all models are returned. Use GkeInferenceQuickstart.FetchModels to find available models.

Returns:

  • (::String)

    Optional. The model to filter profiles by. Open-source models follow the Huggingface Hub owner/model_name format. If not provided, all models are returned. Use GkeInferenceQuickstart.FetchModels to find available models.



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#model_server::String

Returns Optional. The model server to filter profiles by. If not provided, all model servers are returned. Use GkeInferenceQuickstart.FetchModelServers to find available model servers for a given model.

Returns:

  • (::String)

    Optional. The model server to filter profiles by. If not provided, all model servers are returned. Use GkeInferenceQuickstart.FetchModelServers to find available model servers for a given model.



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#model_server_version::String

Returns Optional. The model server version to filter profiles by. If not provided, all model server versions are returned. Use GkeInferenceQuickstart.FetchModelServerVersions to find available versions for a given model and server.

Returns:

  • (::String)

    Optional. The model server version to filter profiles by. If not provided, all model server versions are returned. Use GkeInferenceQuickstart.FetchModelServerVersions to find available versions for a given model and server.



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The target number of results to return in a single response. If not specified, a default value will be chosen by the service. Note that the response may include a partial list and a caller should only rely on the response's next_page_token to determine if there are more instances left to be queried.

Returns:

  • (::Integer)

    Optional. The target number of results to return in a single response. If not specified, a default value will be chosen by the service. Note that the response may include a partial list and a caller should only rely on the response's next_page_token to determine if there are more instances left to be queried.



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The value of next_page_token received from a previous FetchProfilesRequest call. Provide this to retrieve the subsequent page in a multi-page list of results. When paginating, all other parameters provided to FetchProfilesRequest must match the call that provided the page token.

Returns:

  • (::String)

    Optional. The value of next_page_token received from a previous FetchProfilesRequest call. Provide this to retrieve the subsequent page in a multi-page list of results. When paginating, all other parameters provided to FetchProfilesRequest must match the call that provided the page token.



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#performance_requirements::Google::Cloud::GkeRecommender::V1::PerformanceRequirements

Returns Optional. The performance requirements to filter profiles. Profiles that do not meet these requirements are filtered out. If not provided, all profiles are returned.

Returns:



243
244
245
246
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 243

class FetchProfilesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end