Class: Google::Cloud::GkeRecommender::V1::FetchProfilesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb

Overview

Response message for GkeInferenceQuickstart.FetchProfiles.

Instance Attribute Summary collapse

Instance Attribute Details

#comments::String (readonly)

Returns Output only. Additional comments related to the response.

Returns:

  • (::String)

    Output only. Additional comments related to the response.



375
376
377
378
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 375

class FetchProfilesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String (readonly)

Returns Output only. A token which may be sent as [page_token][FetchProfilesResponse.page_token] in a subsequent FetchProfilesResponse call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return.

Returns:

  • (::String)

    Output only. A token which may be sent as [page_token][FetchProfilesResponse.page_token] in a subsequent FetchProfilesResponse call to retrieve the next page of results. If this field is omitted or empty, then there are no more results to return.



375
376
377
378
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 375

class FetchProfilesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#performance_range::Google::Cloud::GkeRecommender::V1::PerformanceRange (readonly)

Returns Output only. The combined range of performance values observed across all profiles in this response.

Returns:



375
376
377
378
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 375

class FetchProfilesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#profile::Array<::Google::Cloud::GkeRecommender::V1::Profile> (readonly)

Returns Output only. List of profiles that match the given model server info and performance requirements (if provided).

Returns:



375
376
377
378
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 375

class FetchProfilesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end