Class: Google::Cloud::GkeRecommender::V1::ResourcesUsed

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb

Overview

Resources used by a model deployment.

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_count::Integer (readonly)

Returns Output only. The number of accelerators (e.g., GPUs or TPUs) used by the model deployment on the Kubernetes node.

Returns:

  • (::Integer)

    Output only. The number of accelerators (e.g., GPUs or TPUs) used by the model deployment on the Kubernetes node.



411
412
413
414
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 411

class ResourcesUsed
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end