Class: Google::Cloud::GkeRecommender::V1::Amount
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::Amount
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Represents an amount of money in a specific currency.
Instance Attribute Summary collapse
-
#nanos ⇒ ::Integer
readonly
Output only.
-
#units ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#nanos ⇒ ::Integer (readonly)
Returns Output only. Number of nano (10^-9) units of the amount.
The value must be between -999,999,999 and +999,999,999 inclusive.
If units is positive, nanos must be positive or zero.
If units is zero, nanos can be positive, zero, or negative.
If units is negative, nanos must be negative or zero.
For example $-1.75 is represented as units=-1 and nanos=-750,000,000.
281 282 283 284 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 281 class Amount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#units ⇒ ::Integer (readonly)
Returns Output only. The whole units of the amount.
For example if currencyCode is "USD", then 1 unit is one US dollar.
281 282 283 284 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 281 class Amount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |