Class: Google::Cloud::GkeRecommender::V1::FetchBenchmarkingDataRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::FetchBenchmarkingDataRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Request message for GkeInferenceQuickstart.FetchBenchmarkingData.
Instance Attribute Summary collapse
-
#instance_type ⇒ ::String
Optional.
-
#model_server_info ⇒ ::Google::Cloud::GkeRecommender::V1::ModelServerInfo
Required.
-
#pricing_model ⇒ ::String
Optional.
Instance Attribute Details
#instance_type ⇒ ::String
Returns Optional. The instance type to filter benchmarking data. Instance types are
in the format a2-highgpu-1g. If not provided, all instance types for the
given profile's model_server_info will be returned. Use
GkeInferenceQuickstart.FetchProfiles
to find available instance types.
184 185 186 187 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 184 class FetchBenchmarkingDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#model_server_info ⇒ ::Google::Cloud::GkeRecommender::V1::ModelServerInfo
Returns Required. The model server configuration to get benchmarking data for. Use GkeInferenceQuickstart.FetchProfiles to find valid configurations.
184 185 186 187 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 184 class FetchBenchmarkingDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pricing_model ⇒ ::String
Returns Optional. The pricing model to use for the benchmarking data. Defaults to
spot.
184 185 186 187 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 184 class FetchBenchmarkingDataRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |