Class: Google::Cloud::GkeRecommender::V1::PerformanceRange
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::PerformanceRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Performance range for a model deployment.
Instance Attribute Summary collapse
-
#ntpot_range ⇒ ::Google::Cloud::GkeRecommender::V1::MillisecondRange
readonly
Output only.
-
#throughput_output_range ⇒ ::Google::Cloud::GkeRecommender::V1::TokensPerSecondRange
readonly
Output only.
-
#ttft_range ⇒ ::Google::Cloud::GkeRecommender::V1::MillisecondRange
readonly
Output only.
Instance Attribute Details
#ntpot_range ⇒ ::Google::Cloud::GkeRecommender::V1::MillisecondRange (readonly)
Returns Output only. The range of NTPOT (Normalized Time Per Output Token) in milliseconds. NTPOT is the request latency normalized by the number of output tokens, measured as request_latency / total_output_tokens.
351 352 353 354 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 351 class PerformanceRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#throughput_output_range ⇒ ::Google::Cloud::GkeRecommender::V1::TokensPerSecondRange (readonly)
Returns Output only. The range of throughput in output tokens per second. This is measured as total_output_tokens_generated_by_server / elapsed_time_in_seconds.
351 352 353 354 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 351 class PerformanceRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ttft_range ⇒ ::Google::Cloud::GkeRecommender::V1::MillisecondRange (readonly)
Returns Output only. The range of TTFT (Time To First Token) in milliseconds. TTFT is the time it takes to generate the first token for a request.
351 352 353 354 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 351 class PerformanceRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |