Class: Google::Cloud::GkeRecommender::V1::PerformanceRequirements
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::PerformanceRequirements
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Performance requirements for a profile and or model deployment.
Instance Attribute Summary collapse
-
#target_cost ⇒ ::Google::Cloud::GkeRecommender::V1::Cost
Optional.
-
#target_ntpot_milliseconds ⇒ ::Integer
Optional.
-
#target_ttft_milliseconds ⇒ ::Integer
Optional.
Instance Attribute Details
#target_cost ⇒ ::Google::Cloud::GkeRecommender::V1::Cost
Returns Optional. The target cost for running a profile's model server. If not provided, this requirement will not be enforced.
263 264 265 266 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 263 class PerformanceRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_ntpot_milliseconds ⇒ ::Integer
Returns Optional. The target Normalized Time Per Output Token (NTPOT) in
milliseconds. NTPOT is calculated as request_latency /
total_output_tokens. If not provided, this target will not be enforced.
263 264 265 266 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 263 class PerformanceRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_ttft_milliseconds ⇒ ::Integer
Returns Optional. The target Time To First Token (TTFT) in milliseconds. TTFT is the time it takes to generate the first token for a request. If not provided, this target will not be enforced.
263 264 265 266 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 263 class PerformanceRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |