Class: Google::Cloud::GkeRecommender::V1::StorageConfig
- Inherits:
-
Object
- Object
- Google::Cloud::GkeRecommender::V1::StorageConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb
Overview
Storage configuration for a model deployment.
Instance Attribute Summary collapse
-
#model_bucket_uri ⇒ ::String
Optional.
-
#xla_cache_bucket_uri ⇒ ::String
Optional.
Instance Attribute Details
#model_bucket_uri ⇒ ::String
Returns Optional. The Google Cloud Storage bucket URI to load the model from. This
URI must point to the directory containing the model's config file
(config.json) and model weights. A tuned GCSFuse setup can improve
LLM Pod startup time by more than 7x. Expected format:
gs://<bucket-name>/<path-to-model>.
551 552 553 554 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 551 class StorageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#xla_cache_bucket_uri ⇒ ::String
Returns Optional. The URI for the GCS bucket containing the XLA compilation cache.
If using TPUs, the XLA cache will be written to the same path as
model_bucket_uri. This can speed up vLLM model preparation for repeated
deployments.
551 552 553 554 |
# File 'proto_docs/google/cloud/gkerecommender/v1/gkerecommender.rb', line 551 class StorageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |